@@ -8,7 +8,7 @@ import backoff.types
 import httpx
 import truststore
 
-from .resources import deployments, documents, models, schemas, projects
+from .resources import documents, models, schemas, projects
 from .types.standards import PreparedRequest, FieldUnset
 
 
@@ -46,7 +46,7 @@ class BaseRetab:
         self,
         api_key: Optional[str] = None,
         base_url: Optional[str] = None,
-        timeout: float = 240.0,
+        timeout: float = 800.0,
         max_retries: int = 3,
         openai_api_key: Optional[str] = FieldUnset,
         gemini_api_key: Optional[str] = FieldUnset,
@@ -180,7 +180,6 @@ class Retab(BaseRetab):
         self.documents = documents.Documents(client=self)
         self.models = models.Models(client=self)
         self.schemas = schemas.Schemas(client=self)
-        self.deployments = deployments.Deployments(client=self)
 
     def _request(
         self,
@@ -439,7 +438,6 @@ class AsyncRetab(BaseRetab):
         self.documents = documents.AsyncDocuments(client=self)
         self.models = models.AsyncModels(client=self)
         self.schemas = schemas.AsyncSchemas(client=self)
-        self.deployments = deployments.AsyncDeployments(client=self)
 
     def _parse_response(self, response: httpx.Response) -> Any:
         """Parse response based on content-type.
