@@ -10,58 +10,66 @@ from openai.types.chat.parsed_chat_completion import ParsedChatCompletionMessage
 
 from ..._resource import AsyncAPIResource, SyncAPIResource
 from ...utils.mime import prepare_mime_document
-from ...utils.ai_models import assert_valid_model_extraction
 from ...utils.stream_context_managers import as_async_context_manager, as_context_manager
 from ...types.documents.create_messages import DocumentCreateInputRequest, DocumentCreateMessageRequest, DocumentMessage
 from ...types.documents.extract import DocumentExtractRequest, RetabParsedChatCompletion, RetabParsedChatCompletionChunk, RetabParsedChoice, maybe_parse_to_pydantic
 from ...types.documents.parse import ParseRequest, ParseResult, TableParsingFormat
 from ...types.browser_canvas import BrowserCanvas
 from ...types.mime import MIMEData
-from ...types.modalities import Modality
-from ...types.ai_models import LLMModel
 from ...types.standards import PreparedRequest, FieldUnset
 from ...utils.json_schema import load_json_schema, unflatten_dict
+from ...types.mime import OCR
+
 
 class BaseDocumentsMixin:
     def _prepare_create_messages(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
-        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> PreparedRequest:
         mime_document = prepare_mime_document(document)
 
-        loading_request_dict = {
-            "document": mime_document,
-            "modality": modality,
-        }
+        loading_request_dict: dict[str, Any] = {"document": mime_document}
         if image_resolution_dpi is not FieldUnset:
             loading_request_dict["image_resolution_dpi"] = image_resolution_dpi
         if browser_canvas is not FieldUnset:
             loading_request_dict["browser_canvas"] = browser_canvas
 
+        # Merge any extra fields provided by the caller
+        if extra_body:
+            loading_request_dict.update(extra_body)
+
         loading_request = DocumentCreateMessageRequest(**loading_request_dict)
         return PreparedRequest(
             method="POST", url="/v1/documents/create_messages", data=loading_request.model_dump(mode="json", exclude_unset=True), idempotency_key=idempotency_key
         )
 
+    def _prepare_get_extraction(self, extraction_id: str) -> PreparedRequest:
+        return PreparedRequest(method="GET", url=f"/v1/extractions/{extraction_id}")
+
+    def _prepare_perform_ocr_only(self, file_id: str) -> PreparedRequest:
+        return PreparedRequest(method="POST", url="/v1/documents/perform_ocr_only", data={"file_id": file_id})
+
+    def _prepare_compute_field_locations(self, ocr_file_id: str, ocr_result: OCR | None = None, data: dict[str, Any] = {}) -> PreparedRequest:
+        return PreparedRequest(method="POST", url="/v1/documents/compute_field_locations", data={"ocr_file_id": ocr_file_id, "ocr_result": ocr_result, "data": data})
+
     def _prepare_create_inputs(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         json_schema: dict[str, Any] | Path | str,
-        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> PreparedRequest:
         mime_document = prepare_mime_document(document)
         loaded_schema = load_json_schema(json_schema)
 
         loading_request_dict = {
             "document": mime_document,
-            "modality": modality,
             "json_schema": loaded_schema,
         }
         if image_resolution_dpi is not FieldUnset:
@@ -69,6 +77,10 @@ class BaseDocumentsMixin:
         if browser_canvas is not FieldUnset:
             loading_request_dict["browser_canvas"] = browser_canvas
 
+        # Merge any extra fields provided by the caller
+        if extra_body:
+            loading_request_dict.update(extra_body)
+
         loading_request = DocumentCreateInputRequest(**loading_request_dict)
         return PreparedRequest(method="POST", url="/v1/documents/create_inputs", data=loading_request.model_dump(mode="json", exclude_unset=True), idempotency_key=idempotency_key)
 
@@ -87,11 +99,12 @@ class BaseDocumentsMixin:
     def _prepare_parse(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
-        model: LLMModel,
+        model: str,
         table_parsing_format: TableParsingFormat = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> PreparedRequest:
         mime_document = prepare_mime_document(document)
 
@@ -106,6 +119,10 @@ class BaseDocumentsMixin:
         if browser_canvas is not FieldUnset:
             request_dict["browser_canvas"] = browser_canvas
 
+        # Merge any extra fields provided by the caller
+        if extra_body:
+            request_dict.update(extra_body)
+
         parse_request = ParseRequest(**request_dict)
         return PreparedRequest(method="POST", url="/v1/documents/parse", data=parse_request.model_dump(mode="json", exclude_unset=True), idempotency_key=idempotency_key)
 
@@ -118,15 +135,13 @@ class BaseDocumentsMixin:
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         temperature: float = FieldUnset,
-        modality: Modality = FieldUnset,
         reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
         n_consensus: int = FieldUnset,
         stream: bool = FieldUnset,
         store: bool = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> PreparedRequest:
-        assert_valid_model_extraction(model)
-
         loaded_schema = load_json_schema(json_schema)
 
         # Handle both single document and multiple documents
@@ -153,8 +168,6 @@ class BaseDocumentsMixin:
             request_dict["store"] = store
         if temperature is not FieldUnset:
             request_dict["temperature"] = temperature
-        if modality is not FieldUnset:
-            request_dict["modality"] = modality
         if reasoning_effort is not FieldUnset:
             request_dict["reasoning_effort"] = reasoning_effort
         if n_consensus is not FieldUnset:
@@ -164,14 +177,16 @@ class BaseDocumentsMixin:
         if browser_canvas is not FieldUnset:
             request_dict["browser_canvas"] = browser_canvas
 
+        # Merge any extra fields provided by the caller
+        if extra_body:
+            request_dict.update(extra_body)
+
         # Validate DocumentAPIRequest data (raises exception if invalid)
         extract_request = DocumentExtractRequest(**request_dict)
 
         # Use the same URL as extractions.py for consistency when streaming
         url = "/v1/documents/extractions" if stream else "/v1/documents/extract"
-        return PreparedRequest(
-            method="POST", url=url, data=extract_request.model_dump(mode="json", exclude_unset=True, exclude_defaults=True), idempotency_key=idempotency_key
-        )
+        return PreparedRequest(method="POST", url=url, data=extract_request.model_dump(mode="json", exclude_unset=True, exclude_defaults=True), idempotency_key=idempotency_key)
 
 
 class Documents(SyncAPIResource, BaseDocumentsMixin):
@@ -183,17 +198,16 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
     def create_messages(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
-        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> DocumentMessage:
         """
         Create document messages from a file using the Retab API.
 
         Args:
             document: The document to process. Can be a file path (Path or str) or a file-like object.
-            modality: The processing modality to use. Defaults to "native".
             image_resolution_dpi: Optional image resolution DPI.
             browser_canvas: Optional browser canvas size.
             idempotency_key: Optional idempotency key for the request
@@ -204,7 +218,11 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
             RetabAPIError: If the API request fails.
         """
         request = self._prepare_create_messages(
-            document=document, modality=modality, image_resolution_dpi=image_resolution_dpi, browser_canvas=browser_canvas, idempotency_key=idempotency_key
+            document=document,
+            image_resolution_dpi=image_resolution_dpi,
+            browser_canvas=browser_canvas,
+            idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = self._client._prepared_request(request)
         return DocumentMessage.model_validate(response)
@@ -213,10 +231,10 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         json_schema: dict[str, Any] | Path | str,
-        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> DocumentMessage:
         """
         Create document inputs (messages with schema) from a file using the Retab API.
@@ -224,7 +242,6 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
         Args:
             document: The document to process. Can be a file path (Path or str), file-like object, MIMEData, PIL Image, or URL.
             json_schema: The JSON schema to use for structuring the document content.
-            modality: The processing modality to use. Defaults to "native".
             image_resolution_dpi: Optional image resolution DPI.
             browser_canvas: Optional browser canvas size.
             idempotency_key: Optional idempotency key for the request
@@ -237,10 +254,10 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
         request = self._prepare_create_inputs(
             document=document,
             json_schema=json_schema,
-            modality=modality,
             image_resolution_dpi=image_resolution_dpi,
             browser_canvas=browser_canvas,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = self._client._prepared_request(request)
         return DocumentMessage.model_validate(response)
@@ -254,11 +271,11 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         temperature: float = FieldUnset,
-        modality: Modality = FieldUnset,
         reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
         n_consensus: int = FieldUnset,
         idempotency_key: str | None = None,
         store: bool = FieldUnset,
+        **extra_body: Any,
     ) -> RetabParsedChatCompletion:
         """
         Process one or more documents using the Retab API for structured data extraction.
@@ -274,7 +291,6 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi: Optional image resolution DPI
             browser_canvas: Optional browser canvas size
             temperature: Model temperature setting (0-1)
-            modality: Modality of the document (e.g., native)
             reasoning_effort: The effort level for the model to reason about the input data
             n_consensus: Number of consensus extractions to perform
             idempotency_key: Idempotency key for request
@@ -295,15 +311,103 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi=image_resolution_dpi,
             browser_canvas=browser_canvas,
             temperature=temperature,
-            modality=modality,
             reasoning_effort=reasoning_effort,
             n_consensus=n_consensus,
             store=store,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = self._client._prepared_request(request)
 
         return maybe_parse_to_pydantic(load_json_schema(json_schema), RetabParsedChatCompletion.model_validate(response))
+        # returns a RetabParsedChatCompletion
+
+    def get_sources(
+        self,
+        extraction_id: str,
+        file: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl | None = None,
+        file_id: str | None = None,
+    ) -> dict[str, Any]:
+        # 1) Get extraction → pick structured data
+        request = self._prepare_get_extraction(extraction_id)
+        extraction_resp = self._client._prepared_request(request)
+
+        # Access completion safely whether dict-like or model-like
+        if isinstance(extraction_resp, dict):
+            completion = extraction_resp.get("completion", {})
+            choices = completion.get("choices", []) or []
+            message = (choices[0].get("message") if choices else {}) or {}
+            parsed = message.get("parsed")
+            if parsed is None:
+                content = message.get("content") or "{}"
+                try:
+                    data: dict[str, Any] = json.loads(content)
+                except Exception:
+                    data = {}
+            else:
+                data = parsed
+        else:
+            # Fallback for attribute-style objects
+            completion = getattr(extraction_resp, "completion", None)
+            choices = getattr(completion, "choices", []) if completion is not None else []
+            message = choices[0].message if choices else None  # type: ignore[attr-defined]
+            parsed = getattr(message, "parsed", None) if message is not None else None
+            if parsed is None and message is not None:
+                try:
+                    data = json.loads(getattr(message, "content", "{}"))
+                except Exception:
+                    data = {}
+            else:
+                data = parsed or {}
+
+        # 2) Determine file_id from provided file or from extraction metadata
+        if not file_id:
+            if file is not None:
+                try:
+                    mime = prepare_mime_document(file)
+                    file_id = mime.id
+                except Exception:
+                    file_id = None
+        if not file_id:
+            candidate_file_ids: list[str] = []
+            if isinstance(extraction_resp, dict):
+                candidate_file_ids = extraction_resp.get("file_ids") or []
+                if not candidate_file_ids:
+                    legacy = extraction_resp.get("file_id")
+                    if legacy:
+                        candidate_file_ids = [legacy]
+            else:
+                candidate_file_ids = getattr(extraction_resp, "file_ids", []) or []
+                if not candidate_file_ids:
+                    legacy = getattr(extraction_resp, "file_id", None)
+                    if legacy:
+                        candidate_file_ids = [legacy]
+            if len(candidate_file_ids) == 1:
+                file_id = candidate_file_ids[0]
+
+        if not isinstance(file_id, str) or not file_id:
+            raise ValueError("Unable to infer file_id. Provide a file path or explicit file_id, or use an extraction with a single file.")
+
+        # 3) OCR the file_id
+        request = self._prepare_perform_ocr_only(file_id)
+        ocr_resp = self._client._prepared_request(request)
+
+        # Support dict or model-like
+        if isinstance(ocr_resp, dict):
+            ocr_file_id = ocr_resp.get("ocr_file_id")
+            ocr_result = ocr_resp.get("ocr_result")
+        else:
+            ocr_file_id = getattr(ocr_resp, "ocr_file_id", None)
+            ocr_result = getattr(ocr_resp, "ocr_result", None)
+
+        # 4) Compute field locations (pass both ocr_file_id and ocr_result to avoid refetch)
+        if not isinstance(ocr_file_id, str) or not ocr_file_id:
+            raise ValueError("perform_ocr_only did not return a valid ocr_file_id")
+        request = self._prepare_compute_field_locations(ocr_file_id, ocr_result, data)
+        field_locations_resp = self._client._prepared_request(request)
+
+        # Caller will decide how to format the return
+        return field_locations_resp
 
     @as_context_manager
     def extract_stream(
@@ -315,11 +419,11 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         temperature: float = FieldUnset,
-        modality: Modality = FieldUnset,
         reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
         n_consensus: int = FieldUnset,
         idempotency_key: str | None = None,
         store: bool = FieldUnset,
+        **extra_body: Any,
     ) -> Generator[RetabParsedChatCompletion, None, None]:
         """
         Process one or more documents using the Retab API with streaming enabled.
@@ -332,7 +436,6 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi: Optional image resolution DPI.
             browser_canvas: Optional browser canvas size.
             temperature: Model temperature setting (0-1)
-            modality: Modality of the document (e.g., native)
             reasoning_effort: The effort level for the model to reason about the input data.
             n_consensus: Number of consensus extractions to perform (default: 1 which computes a single extraction and the likelihoods comes from the model logprobs)
             idempotency_key: Idempotency key for request
@@ -364,12 +467,12 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
             browser_canvas=browser_canvas,
             model=model,
             temperature=temperature,
-            modality=modality,
             reasoning_effort=reasoning_effort,
             stream=True,
             n_consensus=n_consensus,
             store=store,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         schema = load_json_schema(json_schema)
 
@@ -415,11 +518,12 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
     def parse(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
-        model: LLMModel,
+        model: str,
         table_parsing_format: TableParsingFormat = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> ParseResult:
         """
         Parse a document and extract text content from each page.
@@ -448,6 +552,7 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi=image_resolution_dpi,
             browser_canvas=browser_canvas,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = self._client._prepared_request(request)
         return ParseResult.model_validate(response)
@@ -463,17 +568,16 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
     async def create_messages(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image,
-        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> DocumentMessage:
         """
         Create document messages from a file using the Retab API asynchronously.
 
         Args:
             document: The document to process. Can be a file path (Path or str) or a file-like object.
-            modality: The processing modality to use. Defaults to "native".
             idempotency_key: Idempotency key for request
         Returns:
             DocumentMessage: The processed document message containing extracted content.
@@ -483,10 +587,10 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         """
         request = self._prepare_create_messages(
             document=document,
-            modality=modality,
             image_resolution_dpi=image_resolution_dpi,
             browser_canvas=browser_canvas,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = await self._client._prepared_request(request)
         return DocumentMessage.model_validate(response)
@@ -495,10 +599,10 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         json_schema: dict[str, Any] | Path | str,
-        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> DocumentMessage:
         """
         Create document inputs (messages with schema) from a file using the Retab API asynchronously.
@@ -506,7 +610,6 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         Args:
             document: The document to process. Can be a file path (Path or str), file-like object, MIMEData, PIL Image, or URL.
             json_schema: The JSON schema to use for structuring the document content.
-            modality: The processing modality to use. Defaults to "native".
             image_resolution_dpi: Optional image resolution DPI.
             browser_canvas: Optional browser canvas size.
             idempotency_key: Idempotency key for request
@@ -519,10 +622,10 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         request = self._prepare_create_inputs(
             document=document,
             json_schema=json_schema,
-            modality=modality,
             image_resolution_dpi=image_resolution_dpi,
             browser_canvas=browser_canvas,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = await self._client._prepared_request(request)
         return DocumentMessage.model_validate(response)
@@ -536,11 +639,11 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         temperature: float = FieldUnset,
-        modality: Modality = FieldUnset,
         reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
         n_consensus: int = FieldUnset,
         idempotency_key: str | None = None,
         store: bool = FieldUnset,
+        **extra_body: Any,
     ) -> RetabParsedChatCompletion:
         """
         Process one or more documents using the Retab API for structured data extraction asynchronously.
@@ -556,7 +659,6 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi: Optional image resolution DPI
             browser_canvas: Optional browser canvas size
             temperature: Model temperature setting (0-1)
-            modality: Modality of the document (e.g., native)
             reasoning_effort: The effort level for the model to reason about the input data
             n_consensus: Number of consensus extractions to perform
             idempotency_key: Idempotency key for request
@@ -577,11 +679,11 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi=image_resolution_dpi,
             browser_canvas=browser_canvas,
             temperature=temperature,
-            modality=modality,
             reasoning_effort=reasoning_effort,
             n_consensus=n_consensus,
             store=store,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = await self._client._prepared_request(request)
 
@@ -597,11 +699,11 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         temperature: float = FieldUnset,
-        modality: Modality = FieldUnset,
         reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
         n_consensus: int = FieldUnset,
         idempotency_key: str | None = None,
         store: bool = FieldUnset,
+        **extra_body: Any,
     ) -> AsyncGenerator[RetabParsedChatCompletion, None]:
         """
         Extract structured data from one or more documents asynchronously with streaming.
@@ -614,7 +716,6 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi: Optional image resolution DPI.
             browser_canvas: Optional browser canvas size.
             temperature: Model temperature setting (0-1).
-            modality: Modality of the document (e.g., native).
             reasoning_effort: The effort level for the model to reason about the input data.
             n_consensus: Number of consensus extractions to perform (default: 1 which computes a single extraction and the likelihoods comes from the model logprobs)
             idempotency_key: Idempotency key for request
@@ -645,12 +746,12 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
             browser_canvas=browser_canvas,
             model=model,
             temperature=temperature,
-            modality=modality,
             reasoning_effort=reasoning_effort,
             stream=True,
             n_consensus=n_consensus,
             store=store,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         schema = load_json_schema(json_schema)
         ui_parsed_chat_completion_cum_chunk: RetabParsedChatCompletionChunk | None = None
@@ -696,11 +797,12 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
     async def parse(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
-        model: LLMModel,
+        model: str,
         table_parsing_format: TableParsingFormat = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
+        **extra_body: Any,
     ) -> ParseResult:
         """
         Parse a document and extract text content from each page asynchronously.
@@ -729,6 +831,7 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
             image_resolution_dpi=image_resolution_dpi,
             browser_canvas=browser_canvas,
             idempotency_key=idempotency_key,
+            **extra_body,
         )
         response = await self._client._prepared_request(request)
         return ParseResult.model_validate(response)
