@@ -6,35 +6,47 @@ import PIL.Image
 from openai.types.chat.chat_completion_reasoning_effort import ChatCompletionReasoningEffort
 
 from .._resource import AsyncAPIResource, SyncAPIResource
-from ..utils.ai_models import assert_valid_model_schema_generation
 from ..utils.mime import prepare_mime_document_list
 from ..types.mime import MIMEData
-from ..types.modalities import Modality
 from ..types.schemas.generate import GenerateSchemaRequest
-from ..types.standards import PreparedRequest
+from ..types.browser_canvas import BrowserCanvas
+from ..types.standards import PreparedRequest, FieldUnset
 
 
 class SchemasMixin:
     def prepare_generate(
         self,
         documents: Sequence[Path | str | bytes | MIMEData | IOBase | PIL.Image.Image],
-        instructions: str | None = None,
-        model: str = "gpt-5-mini",
-        temperature: float = 0,
-        modality: Modality = "native_fast",
-        reasoning_effort: ChatCompletionReasoningEffort = "minimal",
+        instructions: str | None = FieldUnset,
+        model: str = FieldUnset,
+        temperature: float = FieldUnset,
+        reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
+        **extra_body: Any,
     ) -> PreparedRequest:
-        assert_valid_model_schema_generation(model)
         mime_documents = prepare_mime_document_list(documents)
-        request = GenerateSchemaRequest(
-            documents=mime_documents,
-            instructions=instructions if instructions else None,
-            model=model,
-            temperature=temperature,
-            modality=modality,
-            reasoning_effort=reasoning_effort,
-        )
-        return PreparedRequest(method="POST", url="/v1/schemas/generate", data=request.model_dump())
+        # Build known body and merge in any extras
+        body: dict[str, Any] = {
+            "documents": mime_documents,
+        }
+        if instructions is not FieldUnset:
+            body["instructions"] = instructions
+        if model is not FieldUnset:
+            body["model"] = model
+        if temperature is not FieldUnset:
+            body["temperature"] = temperature
+        if reasoning_effort is not FieldUnset:
+            body["reasoning_effort"] = reasoning_effort
+        if image_resolution_dpi is not FieldUnset:
+            body["image_resolution_dpi"] = image_resolution_dpi
+        if browser_canvas is not FieldUnset:
+            body["browser_canvas"] = browser_canvas
+        if extra_body:
+            body.update(extra_body)
+
+        request = GenerateSchemaRequest(**body)
+        return PreparedRequest(method="POST", url="/v1/schemas/generate", data=request.model_dump(mode="json", exclude_unset=True))
 
 
 class Schemas(SyncAPIResource, SchemasMixin):
@@ -42,16 +54,18 @@ class Schemas(SyncAPIResource, SchemasMixin):
     def generate(
         self,
         documents: Sequence[Path | str | bytes | MIMEData | IOBase | PIL.Image.Image],
-        instructions: str | None = None,
-        model: str = "gpt-5-mini",
-        temperature: float = 0,
-        modality: Modality = "native_fast",
+        instructions: str | None = FieldUnset,
+        model: str = FieldUnset,
+        temperature: float = FieldUnset,
+        reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
+        **extra_body: Any,
     ) -> dict[str, Any]:
         """
         Generate a complete JSON schema by analyzing the provided documents.
 
-        The generated schema includes X-Prompts for enhanced LLM interactions:
-        - X-SystemPrompt: Defines high-level instructions and context for consistent LLM behavior
+        The generated schema can include X-Prompts for enhanced LLM interactions:
         - X-ReasoningPrompt: Creates auxiliary reasoning fields for complex data processing
 
         Args:
@@ -63,8 +77,16 @@ class Schemas(SyncAPIResource, SchemasMixin):
         Raises:
             HTTPException if the request fails
         """
-
-        prepared_request = self.prepare_generate(documents, instructions, model, temperature, modality)
+        prepared_request = self.prepare_generate(
+            documents=documents,
+            instructions=instructions,
+            model=model,
+            temperature=temperature,
+            reasoning_effort=reasoning_effort,
+            image_resolution_dpi=image_resolution_dpi,
+            browser_canvas=browser_canvas,
+            **extra_body,
+        )
         response = self._client._prepared_request(prepared_request)
         return response
 
@@ -73,17 +95,18 @@ class AsyncSchemas(AsyncAPIResource, SchemasMixin):
     async def generate(
         self,
         documents: Sequence[Path | str | bytes | MIMEData | IOBase | PIL.Image.Image],
-        instructions: str | None = None,
-        model: str = "gpt-5-mini",
-        temperature: float = 0.0,
-        modality: Modality = "native_fast",
+        instructions: str | None = FieldUnset,
+        model: str = FieldUnset,
+        temperature: float = FieldUnset,
+        reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
+        **extra_body: Any,
     ) -> dict[str, Any]:
         """
         Generate a complete JSON schema by analyzing the provided documents.
 
-        The generated schema includes X-Prompts for enhanced LLM interactions:
-        - X-SystemPrompt: Defines high-level instructions and context for consistent LLM behavior
-        - X-FieldPrompt: Enhances standard description fields with specific extraction guidance
+        The generated schema can include X-Prompts for enhanced LLM interactions:
         - X-ReasoningPrompt: Creates auxiliary reasoning fields for complex data processing
 
         Args:
@@ -100,7 +123,10 @@ class AsyncSchemas(AsyncAPIResource, SchemasMixin):
             instructions=instructions,
             model=model,
             temperature=temperature,
-            modality=modality,
+            reasoning_effort=reasoning_effort,
+            image_resolution_dpi=image_resolution_dpi,
+            browser_canvas=browser_canvas,
+            **extra_body,
         )
         response = await self._client._prepared_request(prepared_request)
         return response
