@@ -4,14 +4,12 @@ from typing import Any, List, Literal
 
 import PIL.Image
 import requests
-from pydantic import BaseModel, Field, computed_field
+from pydantic import BaseModel, ConfigDict, Field, computed_field
 
 from ...utils.display import count_image_tokens, count_text_tokens
 from ..chat import ChatCompletionRetabMessage
 from ..mime import MIMEData
-from ..modalities import Modality
 from ..browser_canvas import BrowserCanvas
-from ..ai_models import LLMModel
 MediaType = Literal["image/jpeg", "image/png", "image/gif", "image/webp"]
 
 
@@ -22,13 +20,13 @@ class TokenCount(BaseModel):
 
 
 class DocumentCreateMessageRequest(BaseModel):
+    model_config = ConfigDict(extra="ignore")
     document: MIMEData = Field(description="The document to load.")
-    modality: Modality = Field(default="native", description="The modality of the document to load.")
-    image_resolution_dpi: int = Field(default=96, description="Resolution of the image sent to the LLM")
+    image_resolution_dpi: int = Field(default=192, description="Resolution of the image sent to the LLM")
     browser_canvas: BrowserCanvas = Field(
         default="A4", description="Sets the size of the browser canvas for rendering documents in browser-based processing. Choose a size that matches the document type."
     )
-    model: LLMModel = Field(default="gemini-2.5-flash", description="The model to use for the document.")
+    model: str = Field(default="gemini-2.5-flash", description="The model to use for the document.")
 
 class DocumentCreateInputRequest(DocumentCreateMessageRequest):
     json_schema: dict[str, Any] = Field(description="The json schema to use for the document.")
@@ -39,7 +37,6 @@ class DocumentMessage(BaseModel):
     object: Literal["document_message"] = Field(default="document_message", description="The type of object being loaded.")
     messages: List[ChatCompletionRetabMessage] = Field(description="A list of messages containing the document content and metadata.")
     created: int = Field(description="The Unix timestamp (in seconds) of when the document was loaded.")
-    modality: Modality = Field(default="native", description="The modality of the document to load.")
 
     @computed_field
     def token_count(self) -> TokenCount:
