@@ -1,5 +1,6 @@
 import base64
 import datetime
+import json
 from typing import Any, Literal, Optional
 
 
@@ -12,28 +13,19 @@ from openai.types.chat.chat_completion_reasoning_effort import ChatCompletionRea
 from openai.types.chat.parsed_chat_completion import ParsedChatCompletion, ParsedChoice
 from openai.types.responses.response import Response
 from openai.types.responses.response_input_param import ResponseInputItemParam
-from pydantic import BaseModel, ConfigDict, Field, ValidationInfo, computed_field, field_validator, model_validator
-
-from ...utils.usage.usage import CostBreakdown, compute_cost_from_model, compute_cost_from_model_with_breakdown
-from ..ai_models import Amount
+from openai.types.chat.parsed_chat_completion import ParsedChatCompletionMessage
+from pydantic import BaseModel, ConfigDict, Field, ValidationInfo, field_validator, model_validator
 from ..chat import ChatCompletionRetabMessage
 from ..mime import MIMEData
-from ..modalities import Modality
-from ..browser_canvas import BrowserCanvas
 from ..standards import ErrorDetail, StreamingBaseModel
-from ...utils.json_schema import filter_auxiliary_fields_json, convert_basemodel_to_partial_basemodel, convert_json_schema_to_basemodel
-
-
+from ...utils.json_schema import filter_auxiliary_fields_json, convert_basemodel_to_partial_basemodel, convert_json_schema_to_basemodel, unflatten_dict
+from ..modality import Modality
 
 class DocumentExtractRequest(BaseModel):
-    model_config = ConfigDict(arbitrary_types_allowed=True)
+    model_config = ConfigDict(arbitrary_types_allowed=True, extra="ignore")
     document: MIMEData = Field(default=None, description="Document to be analyzed", deprecated=True)  # type: ignore
     documents: list[MIMEData] = Field(default=[], description="Documents to be analyzed (preferred over document)")
-    modality: Modality = Field(default="native", description="Modality of the document")
-    image_resolution_dpi: int = Field(default=96, description="Resolution of the image sent to the LLM")
-    browser_canvas: BrowserCanvas = Field(
-        default="A4", description="Sets the size of the browser canvas for rendering documents in browser-based processing. Choose a size that matches the document type."
-    )
+    image_resolution_dpi: int = Field(default=192, description="Resolution of the image sent to the LLM", ge=96, le=300)
     model: str = Field(..., description="Model used for chat completion")
     json_schema: dict[str, Any] = Field(..., description="JSON schema format used to validate the output data.")
     temperature: float = Field(default=0.0, description="Temperature for sampling. If not provided, the default temperature for the model will be used.", examples=[0.0])
@@ -46,6 +38,8 @@ class DocumentExtractRequest(BaseModel):
     seed: int | None = Field(default=None, description="Seed for the random number generator. If not provided, a random seed will be generated.", examples=[None])
     store: bool = Field(default=True, description="If true, the extraction will be stored in the database")
     need_validation: bool = Field(default=False, description="If true, the extraction will be validated against the schema")
+    modality: Modality = Field(default="native", description="The modality of the document to be analyzed")
+    parallel_ocr_keys: Optional[dict[str, str]] = Field(default=None, description="If set, keys to be used for the extraction of long lists of data using Parallel OCR", examples=[{"properties": "ID", "products": "identity.id"}])
 
     # Add a model validator that rejects n_consensus > 1 if temperature is 0
     @field_validator("n_consensus")
@@ -94,7 +88,7 @@ class FieldLocation(BaseModel):
     page: int | None = Field(default=None, description="The page number of the field (1-indexed)")
     bbox_normalized: tuple[float, float, float, float] | None = Field(default=None, description="The normalized bounding box of the field")
     score: float | None = Field(default=None, description="The score of the field")
-    match_level: Literal["token", "line", "block"] | None = Field(default=None, description="The level of the match (token, line, block)")
+    match_level: Literal["token", "line", "block", "token-windows"] | None = Field(default=None, description="The level of the match (token, line, block, token-windows)")
 
 
 class RetabParsedChoice(ParsedChoice):
@@ -108,29 +102,23 @@ LikelihoodsSource = Literal["consensus", "log_probs"]
 
 
 class RetabParsedChatCompletion(ParsedChatCompletion):
+    model_config = ConfigDict(arbitrary_types_allowed=True, extra="ignore")
+    
     extraction_id: str | None = None
     choices: list[RetabParsedChoice]  # type: ignore
-    # Additional metadata fields (UIForm)
+    # Additional metadata fields
     likelihoods: Optional[dict[str, Any]] = Field(
         default=None, description="Object defining the uncertainties of the fields extracted when using consensus. Follows the same structure as the extraction object."
     )
+
+    requires_human_review: bool = Field(default=False, description="If true, the extraction requires human review")
     schema_validation_error: ErrorDetail | None = None
     # Timestamps
     request_at: datetime.datetime | None = Field(default=None, description="Timestamp of the request")
     first_token_at: datetime.datetime | None = Field(default=None, description="Timestamp of the first token of the document. If non-streaming, set to last_token_at")
     last_token_at: datetime.datetime | None = Field(default=None, description="Timestamp of the last token of the document")
 
-    @computed_field
-    @property
-    def api_cost(self) -> Optional[Amount]:
-        if self.usage:
-            try:
-                cost = compute_cost_from_model(self.model, self.usage)
-                return cost
-            except Exception as e:
-                print(f"Error computing cost: {e}")
-                return None
-        return None
+ 
 
 
 class UiResponse(Response):
@@ -238,29 +226,7 @@ class RetabParsedChatCompletionChunk(StreamingBaseModel, ChatCompletionChunk):
     first_token_at: datetime.datetime | None = Field(default=None, description="Timestamp of the first token of the document. If non-streaming, set to last_token_at")
     last_token_at: datetime.datetime | None = Field(default=None, description="Timestamp of the last token of the document")
 
-    @computed_field
-    @property
-    def api_cost(self) -> Optional[Amount]:
-        if self.usage:
-            try:
-                cost = compute_cost_from_model(self.model, self.usage)
-                return cost
-            except Exception as e:
-                print(f"Error computing cost: {e}")
-                return None
-        return None
-
-    @computed_field  # type: ignore
-    @property
-    def cost_breakdown(self) -> Optional[CostBreakdown]:
-        if self.usage:
-            try:
-                cost = compute_cost_from_model_with_breakdown(self.model, self.usage)
-                return cost
-            except Exception as e:
-                print(f"Error computing cost: {e}")
-                return None
-        return None
+   
 
     def chunk_accumulator(self, previous_cumulated_chunk: "RetabParsedChatCompletionChunk | None" = None) -> "RetabParsedChatCompletionChunk":
         """
@@ -297,7 +263,6 @@ class RetabParsedChatCompletionChunk(StreamingBaseModel, ChatCompletionChunk):
         acc_key_mapping = [safe_get_delta(previous_cumulated_chunk, i).key_mapping or safe_get_delta(self, i).key_mapping for i in range(max_choices)]
 
         acc_content = [(safe_get_delta(previous_cumulated_chunk, i).content or "") + (safe_get_delta(self, i).content or "") for i in range(max_choices)]
-        usage = self.usage
         first_token_at = self.first_token_at
         last_token_at = self.last_token_at
         request_at = self.request_at
@@ -308,7 +273,7 @@ class RetabParsedChatCompletionChunk(StreamingBaseModel, ChatCompletionChunk):
             created=self.created,
             model=self.model,
             object=self.object,
-            usage=usage,
+            usage=None,
             choices=[
                 RetabParsedChoiceChunk(
                     delta=RetabParsedChoiceDeltaChunk(
@@ -330,6 +295,50 @@ class RetabParsedChatCompletionChunk(StreamingBaseModel, ChatCompletionChunk):
             last_token_at=last_token_at,
         )
 
+    def to_completion(
+        self,
+        override_final_flat_likelihoods: dict[str, Any] | None = None,
+        override_final_flat_parseds: list[dict[str, Any]] | None = None,
+    ) -> RetabParsedChatCompletion:
+        if override_final_flat_parseds is None:
+            override_final_flat_parseds = [self.choices[idx].delta.flat_parsed for idx in range(len(self.choices))]
+
+        final_parsed_list = [unflatten_dict(override_final_flat_parseds[idx]) for idx in range(len(self.choices))]
+        final_content_list = [json.dumps(final_parsed_list[idx]) for idx in range(len(self.choices))]
+
+        # The final likelihoods are only on the first choice.
+        if override_final_flat_likelihoods is None:
+            override_final_flat_likelihoods = self.choices[0].delta.flat_likelihoods
+
+        final_likelihoods = unflatten_dict(override_final_flat_likelihoods)
+
+        return RetabParsedChatCompletion(
+            extraction_id=self.extraction_id,
+            id=self.id,
+            created=self.created,
+            model=self.model,
+            object="chat.completion",
+            choices=[
+                RetabParsedChoice(
+                    index=idx,
+                    message=ParsedChatCompletionMessage(
+                        content=final_content_list[idx],
+                        role="assistant",
+                        parsed=final_parsed_list[idx],
+                    ),
+                    key_mapping=self.choices[idx].delta.key_mapping,
+                    finish_reason="stop",
+                    logprobs=None,
+                )
+                for idx in range(len(self.choices))
+            ],
+            likelihoods=final_likelihoods,
+            usage=self.usage,
+            request_at=self.request_at,
+            first_token_at=self.first_token_at,
+            last_token_at=self.last_token_at,
+        )
+
 
 def maybe_parse_to_pydantic(schema: dict[str, Any], response: RetabParsedChatCompletion, allow_partial: bool = False) -> RetabParsedChatCompletion:
     if response.choices[0].message.content:
@@ -345,5 +354,3 @@ def maybe_parse_to_pydantic(schema: dict[str, Any], response: RetabParsedChatCom
             # instead of leaving it as a raw dictionary
             response.choices[0].message.parsed = None
     return response
-
-
