@@ -1,9 +1,8 @@
 from typing import Literal
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, ConfigDict, Field
 
 from ..mime import MIMEData, BaseMIMEData
 from ..browser_canvas import BrowserCanvas
-from ..ai_models import LLMModel
 
 TableParsingFormat = Literal["markdown", "yaml", "html", "json"]
 
@@ -17,11 +16,12 @@ class RetabUsage(BaseModel):
 
 class ParseRequest(BaseModel):
     """Request model for document parsing."""
+    model_config = ConfigDict(extra="ignore")
 
     document: MIMEData = Field(..., description="Document to parse")
-    model: LLMModel = Field(default="gemini-2.5-flash", description="Model to use for parsing")
+    model: str = Field(default="gemini-2.5-flash", description="Model to use for parsing")
     table_parsing_format: TableParsingFormat = Field(default="html", description="Format for parsing tables")
-    image_resolution_dpi: int = Field(default=96, description="DPI for image processing")
+    image_resolution_dpi: int = Field(default=192, description="DPI for image processing", ge=96, le=300)
     browser_canvas: BrowserCanvas = Field(default="A4", description="Canvas size for document rendering")
 
 
