@@ -11,7 +11,7 @@ T = TypeVar("T")
 
 # Global test constants
 TEST_MODEL = "gpt-4.1-nano"
-TEST_MODALITY = "native_fast"
+TEST_MODALITY = "native"
 
 
 async def await_or_return(obj: T | Awaitable[T]) -> T:
@@ -43,14 +43,14 @@ async def test_evaluation_crud_basic(
     client = sync_client if client_type == "sync" else async_client
 
     # CREATE - Create a new evaluation
-    evaluation = await await_or_return(client.projects.create(name=evaluation_name, json_schema=booking_confirmation_json_schema))
+    project = await await_or_return(client.projects.create(name=evaluation_name, json_schema=booking_confirmation_json_schema))
 
-    assert evaluation.name == evaluation_name
-    assert evaluation.json_schema == booking_confirmation_json_schema
-    assert len(evaluation.documents) == 0
-    assert len(evaluation.iterations) == 0
+    assert project.name == evaluation_name
+    assert project.json_schema == booking_confirmation_json_schema
+    assert len(project.documents) == 0
+    assert len(project.iterations) == 0
 
-    project_id = evaluation.id
+    project_id = project.id
 
     try:
         # READ - Get the evaluation by ID
@@ -96,14 +96,14 @@ async def test_evaluation_with_documents(
     client = sync_client if client_type == "sync" else async_client
 
     # Create an evaluation
-    evaluation = await await_or_return(
+    project = await await_or_return(
         client.projects.create(
             name=evaluation_name,
             json_schema=booking_confirmation_json_schema,
         )
     )
 
-    project_id = evaluation.id
+    project_id = project.id
 
     try:
         # CREATE - Add a document
@@ -173,14 +173,14 @@ async def test_iteration_crud_and_processing(
     client = sync_client if client_type == "sync" else async_client
 
     # First create an evaluation
-    evaluation = await await_or_return(
+    project = await await_or_return(
         client.projects.create(
             name=evaluation_name,
             json_schema=booking_confirmation_json_schema,
         )
     )
 
-    project_id = evaluation.id
+    project_id = project.id
 
     try:
         # Add a document to the evaluation
@@ -270,14 +270,14 @@ async def test_process_document_method(
     client = sync_client if client_type == "sync" else async_client
 
     # Create an evaluation
-    evaluation = await await_or_return(
+    project = await await_or_return(
         client.projects.create(
             name=evaluation_name,
             json_schema=booking_confirmation_json_schema,
         )
     )
 
-    project_id = evaluation.id
+    project_id = project.id
 
     try:
         # Add a document to the evaluation
@@ -361,14 +361,14 @@ async def test_complete_evaluation_workflow(
     client = sync_client if client_type == "sync" else async_client
 
     # Step 1: Create an evaluation
-    evaluation = await await_or_return(
+    project = await await_or_return(
         client.projects.create(
             name=evaluation_name,
             json_schema=booking_confirmation_json_schema,
         )
     )
 
-    project_id = evaluation.id
+    project_id = project.id
 
     try:
         # Step 2: Add 2 documents
@@ -479,6 +479,58 @@ async def test_complete_evaluation_workflow(
             pass
 
 
+@pytest.mark.asyncio
+@pytest.mark.parametrize("client_type", get_args(ClientType))
+async def test_extract_without_iteration_id(
+    sync_client: Retab,
+    async_client: AsyncRetab,
+    client_type: ClientType,
+    booking_confirmation_file_path_1: str,
+    booking_confirmation_json_schema: Dict[str, Any],
+) -> None:
+    """Ensure extract works when iteration_id is omitted (defaults to base configuration)."""
+    evaluation_name = f"test_extract_no_iter_{nanoid.generate()}"
+    client = sync_client if client_type == "sync" else async_client
+
+    # Create a project
+    project = await await_or_return(
+        client.projects.create(
+            name=evaluation_name,
+            json_schema=booking_confirmation_json_schema,
+        )
+    )
+
+    project_id = project.id
+
+    try:
+        # Call extract without providing iteration_id
+        completion_response = await await_or_return(
+            client.projects.extract(
+                project_id=project_id,
+                document=booking_confirmation_file_path_1,
+            )
+        )
+
+        # Validate the response
+        assert isinstance(completion_response, RetabParsedChatCompletion)
+        assert completion_response.choices is not None
+        assert len(completion_response.choices) > 0
+        assert completion_response.choices[0].message.content is not None
+
+        # The parsed content should be valid JSON
+        try:
+            parsed_content = json.loads(completion_response.choices[0].message.content)
+            assert isinstance(parsed_content, dict)
+        except json.JSONDecodeError:
+            assert False, "Response content should be valid JSON"
+
+    finally:
+        # Cleanup
+        try:
+            await await_or_return(client.projects.delete(project_id))
+        except Exception:
+            pass
+
 @pytest.mark.asyncio
 @pytest.mark.parametrize("client_type", get_args(ClientType))
 async def test_iteration_selective_processing(
@@ -496,14 +548,14 @@ async def test_iteration_selective_processing(
     client = sync_client if client_type == "sync" else async_client
 
     # Create an evaluation
-    evaluation = await await_or_return(
+    project = await await_or_return(
         client.projects.create(
             name=evaluation_name,
             json_schema=booking_confirmation_json_schema,
         )
     )
 
-    project_id = evaluation.id
+    project_id = project.id
 
     try:
         # Add multiple documents
